@@ -17,6 +17,8 @@ from neural_semigroups.associator_loss import AssociatorLoss
 from neural_semigroups.constant_baseline import ConstantBaseline
 from neural_semigroups.cyclic_group import CyclicGroup
 from neural_semigroups.denoising_autoencoder import MagmaDAE
+from neural_semigroups.mace4_semigroups_dataset import Mace4Semigroups
 from neural_semigroups.magma import Magma
 from neural_semigroups.precise_guess_loss import PreciseGuessLoss
+from neural_semigroups.semigroups_dataset import SemigroupsDataset
 from neural_semigroups.smallsemi_dataset import Smallsemi
